@@ -694,7 +694,7 @@ class UserSettings(View):
                 act_as_button_text=_("Act as another user"),
                 act_as_self_text=_("Stop acting as another user"),
                 # #3070: Add id and the text of "My setting" menu
-                my_setting_text=_("My settings"),
+                my_setting_text=settings.SITE.plugins.users.my_setting_text,
                 user_id=u.pk,
             )
             if separate_site_cache_root:
